#[non_exhaustive]pub enum RawRdEnvironment {
Global,
Base,
Empty,
Other,
}Expand description
The environment categories exposed by a producer when preserving a raw value. Environment frames are intentionally not part of the Rd AST.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.