pub struct UnexpectedRawNode { /* private fields */ }Expand description
Details explaining why a Raw node did not match the pinned shape.
Implementations
Sourceimpl UnexpectedRawNode
impl UnexpectedRawNode
pub fn tag(&self) -> Option<&str>
pub fn reason(&self) -> &RawNodeReason
pub fn offending_attributes(&self) -> &[String]
Sourceimpl UnexpectedRawNode
impl UnexpectedRawNode
Sourcepub fn shape_error(&self, path: RdPath) -> RdShapeError
pub fn shape_error(&self, path: RdPath) -> RdShapeError
Converts corpus classification details into the shared shape vocabulary.